package v1
import "k8s.io/component-base/tracing/api/v1"
Index ¶
- func ValidateTracingConfiguration(traceConfig *TracingConfiguration, featureGate featuregate.FeatureGate, fldPath *field.Path) field.ErrorList
- type TracingConfiguration
Functions ¶
func ValidateTracingConfiguration ¶
func ValidateTracingConfiguration(traceConfig *TracingConfiguration, featureGate featuregate.FeatureGate, fldPath *field.Path) field.ErrorList
ValidateTracingConfiguration validates the tracing configuration
Types ¶
type TracingConfiguration ¶
type TracingConfiguration struct {
// Endpoint of the collector this component will report traces to.
// The connection is insecure, and does not currently support TLS.
// Recommended is unset, and endpoint is the otlp grpc default, localhost:4317.
// +optional
Endpoint *string `json:"endpoint,omitempty"`
// SamplingRatePerMillion is the number of samples to collect per million spans.
// Recommended is unset. If unset, sampler respects its parent span's sampling
// rate, but otherwise never samples.
// +optional
SamplingRatePerMillion *int32 `json:"samplingRatePerMillion,omitempty"`
}
TracingConfiguration provides versioned configuration for OpenTelemetry tracing clients.
func (*TracingConfiguration) DeepCopy ¶
func (in *TracingConfiguration) DeepCopy() *TracingConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TracingConfiguration.
func (*TracingConfiguration) DeepCopyInto ¶
func (in *TracingConfiguration) DeepCopyInto(out *TracingConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (TracingConfiguration) OpenAPIModelName ¶
func (in TracingConfiguration) OpenAPIModelName() string
OpenAPIModelName returns the OpenAPI model name for this type.
Source Files ¶
config.go doc.go types.go zz_generated.deepcopy.go zz_generated.model_name.go
- Version
- v0.35.0 (latest)
- Published
- Dec 17, 2025
- Platform
- linux/amd64
- Imports
- 5 packages
- Last checked
- 4 months ago –
Tools for package owners.